from django.contrib.auth.decorators import login_required
from django.http import JsonResponse
from django.views.decorators.http import require_POST
from .oss import upload_to_oss


@require_POST
@login_required
def upload_view(request):
    try:
        image_file = request.FILES["image"]
        oss_url = upload_to_oss(image_file, request.user.id)
        return JsonResponse({"url": oss_url})
    except Exception as e:
        return JsonResponse({"error": str(e)}, status=400)



from django.conf import settings
from django.views.decorators.http import require_POST
from django.core.exceptions import ImproperlyConfigured
import oss2
from .defaults import get_oss_config


def get_oss_config():
    return getattr(
        settings,
        "DJ_IMAGE_UPLOADER_OSS_CONFIG",
        {
            "ACCESS_KEY_ID": "your_key_id",
            "ACCESS_KEY_SECRET": "your_secret",
            "ENDPOINT": "oss-cn-beijing.aliyuncs.com",
            "BUCKET_NAME": "your_bucket",
            "BASE_PATH": "uploads/",
        },
    )


def upload_to_oss(file_obj, user_id=None):
    config = get_oss_config()

    try:
        auth = oss2.Auth(config["ACCESS_KEY_ID"], config["ACCESS_KEY_SECRET"])
        bucket = oss2.Bucket(auth, config["ENDPOINT"], config["BUCKET_NAME"])

        filename = f"{config['BASE_PATH']}{user_id}_{file_obj.name}"
        bucket.put_object(filename, file_obj)
        return f"https://{config['BUCKET_NAME']}.{config['ENDPOINT']}/{filename}"
    except KeyError as e:
        raise ImproperlyConfigured(f"Missing OSS config: {e}")



from django.db import models
from .widgets import ImageUploaderWidget
from django import forms


class ImageUploadField(models.Field):
    def __init__(self, upload_url=None, *args, **kwargs):
        self.upload_url = upload_url
        super().__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            "form_class": ImageUploaderFormField,
            "widget": ImageUploaderWidget(upload_url=self.upload_url),
            "upload_url": self.upload_url,
        }
        defaults.update(kwargs)
        return super().formfield(**defaults)


class ImageUploaderFormField(forms.fields.Field):
    def __init__(self, upload_url=None, *args, **kwargs):
        kwargs.update["widget"]: ImageUploaderWidget(upload_url=upload_url)
        super().__init__(*args, **kwargs)



from django import forms
from django.forms import widgets
from django.utils.safestring import mark_safe


class ImageUploaderWidget(widgets.URLInput):
    template_name = "uploader.html"

    def __init__(self, upload_url, attrs=None):
        self.upload_url = upload_url
        super().__init__(attrs)

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context["widget"]["upload_url"] = self.upload_url
        context["widget"]["value"] = value
        return context

    class Media:
        css = {"all": ("image_uploader_widget/css/uploader.css",)}
        js = ("image_uploader_widget/js/uploader.js",)



from setuptools import setup, find_packages

setup(
    name="dj-image-uploader-widget",
    version="0.4.2",
    packages=find_packages(),
    include_package_data=True,
    install_requires=["Django>=4.0", "oss2>=2.15.0"],
    description="Django OSS Image Upload Widget with Customizable Configuration",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/ren000thomas/dj-image-uploader-widget",
    author="Ren Thomas",
    author_email="ren000thomas@gmail.com",
    classifiers=[
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
